==> alfred-ui-native-components-0.0.94.tgz: package/ui/organisms/modal/bodies/IconTitleDoubleDescriptionsDoubleButtons/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { BodyRegularText,
  PrimaryLargeTextSolidButton,
  SecondaryLargeTextSolidButton,
  SubtitleSemiBoldText } from '../../../../atoms';
import { TitleCloseModalHeader } from '../../../../molecules';
import { IconTitleDoubleDescriptionsDoubleButtonsModalModel } from '../modalBodiesModels';
import { styles } from './styles';

export const IconTitleDoubleDescriptionsDoubleButtonsModal: FC<IconTitleDoubleDescriptionsDoubleButtonsModalModel> = ({
  Icon,
  title,
  description1,
  description2,
  buttonPositiveText,
  buttonNegativeText,
  onClose,
  onPositiveButtonClick,
  onNegativeButtonClick,
}) => {
  return (
    <View>
      <TitleCloseModalHeader onClose={onClose} />
      <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalContent}>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalIcon}>
          {Icon && <Icon width={'96'} height={'96'} />}
        </View>
        <SubtitleSemiBoldText numberOfLines={2}>
          {title}
        </SubtitleSemiBoldText>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalDescription}>
          <BodyRegularText numberOfLines={5}>
            {description1}
          </BodyRegularText>
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalDescription}>
          <BodyRegularText numberOfLines={2}>
            {description2}
          </BodyRegularText>
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsContainer}>
          <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsColumn}>
            <SecondaryLargeTextSolidButton onClick={onNegativeButtonClick} text={buttonNegativeText} disabled={false} />
          </View>
          <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsColumn}>
            <PrimaryLargeTextSolidButton onClick={onPositiveButtonClick} text={buttonPositiveText} disabled={false} />
          </View>
        </View>
      </View>
    </View>
  );
};

==> alfred-ui-native-components-0.0.99.tgz: package/ui/organisms/modal/bodies/IconTitleDoubleDescriptionsDoubleButtons/index.tsx <==
import React, { FC } from 'react';
import { View } from 'react-native';
import { BodyRegularText,
  PrimaryLargeTextSolidButton,
  SecondaryLargeTextSolidButton,
  SubtitleSemiBoldText } from '../../../../atoms';
import { TitleCloseModalHeader } from '../../../../molecules';
import { IconTitleDoubleDescriptionsDoubleButtonsModalModel } from '../modalBodiesModels';
import { styles } from './styles';
import { getThemeColorByDefaultColor } from '../../../../../utils';

export const IconTitleDoubleDescriptionsDoubleButtonsModal: FC<IconTitleDoubleDescriptionsDoubleButtonsModalModel> = ({
  Icon,
  title,
  description1,
  description2,
  buttonPositiveText,
  buttonNegativeText,
  onClose,
  onPositiveButtonClick,
  onNegativeButtonClick,
}) => {
  return (
    <View>
      <TitleCloseModalHeader onClose={onClose} />
      <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalContent}>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalIcon}>
          {Icon && <Icon width={'96'} height={'96'} />}
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalDescription}>
          <SubtitleSemiBoldText numberOfLines={2}>
            {title}
          </SubtitleSemiBoldText>
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalDescription}>
          <BodyRegularText numberOfLines={5} color={getThemeColorByDefaultColor('text', 'default')}>
            {description1}
          </BodyRegularText>
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalDescription}>
          <BodyRegularText numberOfLines={2} color={getThemeColorByDefaultColor('text', 'default')}>
            {description2}
          </BodyRegularText>
        </View>
        <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsContainer}>
          <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsColumn}>
            <SecondaryLargeTextSolidButton onClick={onNegativeButtonClick} text={buttonNegativeText} disabled={false} />
          </View>
          <View style={styles.iconTitleDoubleDescriptionsDoubleButtonsModalButtonsColumn}>
            <PrimaryLargeTextSolidButton onClick={onPositiveButtonClick} text={buttonPositiveText} disabled={false} />
          </View>
        </View>
      </View>
    </View>
  );
};
